# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2023/8/25 10:51:57
@Author  : zhchen
@Desc    : 
"""
from lqbox.base import BaseBox


class OcBox(BaseBox):
    base_url = 'aHR0cHM6Ly9vYy5sZXFlZS5jb20='

    def __init__(self, cookies):
        self.token = None
        super().__init__(cookies)

    def check(self):
        super().check()
        self.token = self.cookies.get("token")
        if not self.token:
            raise ValueError("token is None")

    def __oc_request(self, path, json_data):
        return self.request(url=f"{self.base_url}{path}", method="POST", json=json_data)

    def user_info_detail(self):
        """个人信息"""
        return self.__oc_request(
            path="/index.php/tachiba/TachibaServiceBasicInfoController/userInfoDetail",
            json_data={"token": self.token}
        )

    def display_user(self, json_data):
        """用户信息-新版"""
        # json_data = {
        #     "core_user_id": 1234
        # }
        return self.__oc_request(
            path="/ext-hr/api/staffProfile/StaffController/displayUser",
            json_data={**json_data, "token": self.token}
        )

    def assessing_list(self, json_data):
        """绩效列表"""
        # json_data = {
        #     'page': 1,
        #     'limit': 10,
        # }
        return self.__oc_request(
            path="/ext-hr/api/assessment/AssessmentAsAssesseeController/getMySelfAssessingList",
            json_data={**json_data, "token": self.token}
        )

    def assessing_result(self, json_data):
        """绩效具体"""
        # json_data = {
        #     "assessment_code": "2021Q04"
        # }
        return self.__oc_request(
            path="/ext-hr/api/assessment/AssessmentAsAssesseeController/getMySelfAssessingResult",
            json_data={**json_data, "token": self.token}
        )

    def team_building_fee(self, json_data):
        """团建费用"""
        # json_data = {
        #     'page': 1,
        #     'page_size': 10,
        #     'core_user_id': '',
        #     'department_id': '187',
        #     'year': 2021,
        # }
        return self.__oc_request(
            path="/index.php/oa/OaTeambuildingIssueController/getTeambuildingFeeList",
            json_data={**json_data, "token": self.token}
        )



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2024/10/9 13:10:33
@Author  : luke
@Desc    : 
"""
import os

from lqbox.base import BaseBox


class EurekaBox(BaseBox):
    base_url = 'aHR0cHM6Ly9lZS5sZXFlZS5jb20='

    def __init__(self, cookies):
        self.headers = {
            'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                          'Chrome/122.0.0.0 Safari/537.36',
            'Accept': 'application/json, text/plain, */*',
        }
        super().__init__(cookies)

    def chat_file_upload(self, file_path, file_type='image/png'):
        """上传聊天文件"""
        files = {
            'file': (os.path.basename(file_path), open(file_path, 'rb'), file_type),
        }
        response = self.request(
            method='POST',
            url=f'{self.base_url}/ee/proxy/ai/web/eureka/chat/session/file/upload',
            cookies=self.cookies,
            headers=self.headers,
            files=files,
        )
        return response



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2024/9/26 14:19:28
@Author  : luke
@Desc    : 
"""
import time

from requests import Response

from lqbox.base import BaseBox


class OpenCanaryBox(BaseBox):
    base_url = 'aHR0cHM6Ly9mZWxsLXNlcnZlci1raXQubGVxZWUuY29t'

    def __init__(self, tp_code, tp_secret):
        super().__init__(cookies={})
        self.tp_code = tp_code
        self.tp_secret = tp_secret

    def request_open_api(self, api_path, body) -> Response:
        noise = str(time.time() * 1000)
        headers = {
            'content-type': 'application/json',
            'noise': noise,
            'tp-code': self.tp_code,
            'sign': self.md5(f'{self.tp_code}&{noise}&{self.tp_secret}'),
        }
        r = self.request(method="POST", url=f'{self.base_url}{api_path}', json=body, headers=headers)
        return r

    def call_register_one_captcha_execution_record(self, captcha, status="SUCCESS", memo=None):
        data = {
            "captcha": captcha,
            "status": status,
        }
        if memo is not None:
            data['memo'] = memo
        return self.request_open_api(api_path="/open_api/register_one_captcha_execution_record", body=data)

    def call_get_captcha_execution_records(self, captcha, start_time, end_time):
        data = {
            "captcha": captcha,
            "start_time": start_time,
            "end_time": end_time,
        }
        return self.request_open_api(api_path="/open_api/get_captcha_execution_records", body=data)

    def call_register_one_fell_py_exception_record(self, data):
        return self.request_open_api(api_path="/open_api/register_one_py_exception_record", body=data)

    def call_get_fell_path_table_level(self, path_id):
        data = {"path_id": path_id}
        return self.request_open_api(api_path="/open_api/get_fell_path_table_level", body=data)





# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2023/8/25 10:51:45
@Author  : zhchen
@Desc    : 
"""
from lqbox.base import BaseBox


class BidpBox(BaseBox):
    base_url = 'aHR0cHM6Ly9iaWRwLmxlcWVlLmNvbQ=='

    def __init__(self, cookies):
        self.headers = {
            'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) '
                          'Chrome/122.0.0.0 Safari/537.36',
            'authorization': None
        }
        super().__init__(cookies)

    def check(self):
        super().check()
        if not self.cookies.get('token'):
            raise ValueError('cookies中需要包含token')
        self.headers['authorization'] = self.cookies['token']

    def request(self, method, url, **kwargs):
        if kwargs.get('headers') is None:
            kwargs['headers'] = self.headers
        return super().request(method, url, **kwargs)

    def bidp_request(self, path, data, json=False):
        if json:
            return self.request(url=f"{self.base_url}{path}", method="POST", json=data)
        else:
            return self.request(url=f"{self.base_url}{path}", method="POST", data=data)

    # --== 需求模块 ==--
    def demand_detail(self, base_id):
        """需求详情"""
        data = {'baseId': str(base_id)}
        return self.bidp_request(path='/bi/controller/wb/DataWbBase/getDetail', data=data)

    def demand_module(self, base_id):
        """需求详情-成本排期-多人模块"""
        data = {'baseId': str(base_id)}
        return self.bidp_request(path='/bi/controller/wb/module/DataWbModule/getModuleStaff', data=data)

    def demand_module_task(self, base_id, module_id):
        """需求详情-多人模块-具体"""
        data = {
            'baseId': str(base_id),
            'moduleId': str(module_id),
        }
        return self.bidp_request(path='/bi/controller/wb/task/DataWbTask/getModuleTask', data=data)

    def demand_note_list(self, base_id):
        """需求详情-留言列表"""
        data = {'baseId': str(base_id)}
        return self.bidp_request(path='/bi/controller/wb/DataWbNote/listNote', data=data)

    # ++-- 需求模块 --++

    # --== 质量管理中心 ==--
    def monitor_alert_category(self):
        """数据采集中心-异常信息-所有分类"""
        return self.bidp_request(
            path='/bi/controller/crawler/monitor/CrawlerMonitorTaskExecuteResult/getAlertCategory', data={})

    def monitor_alert_list(self, data):
        """数据采集中心-异常信息"""
        # data = {
        #     'alertId': '123',
        #     'category': 'Cookie Invalidated',
        #     'pageNum': '1',
        #     'pageSize': '10',
        #     'startTime': '2024-04-10 00:00:00',
        #     'endTime': '2024-04-12 00:00:00',
        # }
        return self.bidp_request(
            path='/bi/controller/crawler/monitor/CrawlerMonitorTaskExecuteResult/alertList', data=data)

    def etl_task_list(self, data):
        """数据任务监控-任务管理"""
        # json_data = {
        #     'tableName': '',
        #     'tableCode': '123',
        #     'jobId': '',
        #     'pageNum': 1,
        #     'pageSize': 300,
        # }
        return self.bidp_request(path='/bi/controller/task/define/list', data=data, json=True)

    def etl_db_task(self, data):
        """入库任务监控-入库任务"""
        # data = {
        #     'taskId': '123',
        #     'pageNum': '1',
        #     'pageSize': '30',
        # }
        return self.bidp_request('/bi/controller/monitor/sync/toDbTask/list', data=data)

    # ++-- 质量管理中心 --++

    # --== 模型设计中心 == --
    def get_path_list(self):
        """模型建设-规范建表-采集路径"""
        return self.bidp_request(path='/bi/controller/crawler/manage/CrawlerManageNodeInfo/getPathList', data={})

    # ++-- 模型设计中心  --++

    # //-- 数据治理中心  --\\
    def search_relation_tables(self, data):
        """血缘分析-搜索血缘"""
        # data = {
        #     'searchInfo': '123',
        # }
        return self.bidp_request(path='/bi/controller/assets/TableRelation/searchTables', data=data)

    def get_relation(self, data):
        """血缘分析-获取血缘关系图"""
        # data = {
        #     'tableName': '123',
        #     'tableType': '123',
        #     'id': '123',
        #     'relationType': '123',
        # }
        return self.bidp_request(path='/bi/controller/assets/TableRelation/getRelation', data=data)

    def relation_table_base_info(self, data):
        """血缘分析-血缘关系图-点击某个节点"""
        # data = {
        #     'tableType': '123',
        #     'id': '123',
        # }
        return self.bidp_request(path='/bi/controller/assets/TableRelation/getBaseInfo', data=data)

    def meta_eb_collection(self, data):
        """元数据管理-数据集元数据-搜索列表页"""
        # data = {
        #     "pageNum": "1",
        #     "pageSize": "123",
        #     "collectionId": "123",
        #     "owner": "123",
        #     "collectionLevel": "123",
        #     "updatePeriod": "123",
        # }
        return self.bidp_request(path='/bi/controller/assets/MetaEbCollection/list', data=data)

    # //-- 数据治理中心  --\\



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py.py
@Date    : 2025/2/8 9:47:09
@Author  : luke
@Desc    : 
"""

from requests import Response

from lqbox.base import BaseBox


class CanaryBox(BaseBox):
    base_url = 'aHR0cHM6Ly9mZWxsLXNlcnZlci1raXQubGVxZWUuY29t'

    def __init__(self):
        super().__init__(cookies={})

    def canary_request(self, api_path, body) -> Response:
        headers = {'content-type': 'application/json'}
        r = self.request(method="POST", url=f'{self.base_url}{api_path}', json=body, headers=headers)
        return r

    def exception_records(self, json_data):
        """查询"""
        # json_data = {
        #     'task_id': '',
        #     'start_time': '',
        #     'end_time': '',
        #     'category': [],
        #     'is_ok': '-1',
        #     'search_user': [],
        #     'search_shovel_name': '',
        #     'search_account_name': '',
        #     'search_level': [],
        # }
        return self.canary_request(api_path="/canary_api/exception_records", body=json_data)

    def mark_exception_records(self, json_data):
        """标记"""
        # json_data = {
        #     'send_data': [
        #         {
        #             'id': 0,
        #             'is_ok': True,
        #             'approval_time': None,
        #         },
        #     ],
        #     'comment': '',
        #     'account_user': '',
        # }
        return self.canary_request(api_path="/canary_api/exception_records/mark/handled", body=json_data)



# -*- coding: utf-8 -*-

"""
@Project : lqbox 
@File    : __init__.py
@Date    : 2023/8/31 13:01:27
@Author  : zhchen
@Desc    : 
"""
import uuid
from typing import Optional

from requests import Response

from lqbox.base import BaseBox


class OpenBidpBox(BaseBox):
    base_url = 'aHR0cHM6Ly9iaWRwLmxlcWVlLmNvbS9vcGVuLXNlcnZpY2U='
    name1 = 'YXBwS2V5'
    name2 = 'bm9uY2U='
    name3 = 'c2lnbg=='

    def __init__(self, app_key, app_secret):
        super().__init__(cookies={})
        self.app_key = app_key
        self.app_secret = app_secret

    def request_open_api(self, api_path, body) -> Response:
        headers = {'content-type': 'application/json'}
        _uuid = str(uuid.uuid4())
        body[self.base64(self.name1)] = self.app_key
        body[self.base64(self.name2)] = _uuid
        body[self.base64(self.name3)] = self.md5(f'{self.app_key}@{_uuid}@{self.app_secret}')
        r = self.request(method="POST", url=f'{self.base_url}/{api_path}', json=body, headers=headers)
        return r

    def call_get_login_acc(self, platform_code=None, shop_list=None, account_id=None, channel=None):
        """获取登录的账号"""
        dictionary = {"platformCodes": platform_code}
        if shop_list is not None:
            dictionary['shopIds'] = shop_list
        if account_id is not None:
            dictionary['accountIds'] = account_id
        if channel is not None:
            dictionary['channel'] = channel
        return self.request_open_api("AccountOpenApi/getLoginAcc", dictionary)

    def call_get_accounts_without_long_session(self, account_id_list, platform_code=None):
        """筛选出没有可用的 LONG 类型的会话的 account_id"""
        d = {'accountIdList': account_id_list}
        if platform_code is not None:
            d['platformCode'] = platform_code
        return self.request_open_api('AccountOpenApi/getAccountsWithoutLongSession', body=d)

    def call_search_data_fetch_records(self, request_entity: dict):
        """检查之前的数据落盘记录，在补录场景下可以减少重复取数"""
        # request_entity的key: shovelProject, shovelClass, limit, aspect, partKey, timeRange, mizarGroupId
        return self.request_open_api('RecordOpenApiController/searchDataFetchRecords', body=request_entity)

    def call_get_account_related_available_sessions(
            self, account_id: int, platform_code: str,
            status: Optional[str] = None, limit: Optional[int] = None):
        """查找某个账号是否有可用会话 (获取session)"""
        dictionary = {
            'accountId': account_id,
            'platformCode': platform_code,
        }
        if status is not None:
            dictionary['status'] = status
        if limit is not None:
            dictionary['limit'] = limit
        else:
            dictionary['limit'] = 1

        return self.request_open_api("AccountOpenApi/getAccountRelatedAvailableSessions", body=dictionary)
